##  Overview
Data quality insight cards at the top of the inventory help you quickly identify and address data quality gaps in the fact sheets you have subscribed to. They surface missing or incomplete data so you can address issues without having to search for them.
Currently, the following information is surfaced:
  * Applications with a missing description
  * Applications with missing lifecycle
  * Missing relations between applications and business capabilities
  * Missing relations between applications and organizations


![Data Quality Insight Cards](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio9f7ee2a70bd147429934cbd02aa99bde_LowRes.png)
Data Quality Insight Cards
**Note**
Data quality insight is an optional feature. Admins can activate from the Optional Feature and Early Access page of the admin area. For more details, see [Activating Data Quality Insights](https://help.sap.com/docs/leanix/ea/data-quality-insights?locale=en-US&state=PRODUCTION&version=CLOUD#loioc9c9b25fc4324c3382fd36bedbdd91b4__activating-data-quality-insights).
